#ifndef FITS2RDB_H
#define FITS2RDB_H

// --8<--8<--8<--8<--
//
// Copyright (C) 2008 Smithsonian Astrophysical Observatory
//
// This file is part of fits2rdb
//
// fits2rdb is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// -->8-->8-->8-->8--

#include <exception>
#include <map>
#include <string>
#include <vector>
#include <float.h>
#include <funtools.h>
#include <suplibxx/colselect.h>
#include <suplibxx/str.h>
using namespace std;

#include "Options.h"

class Fits2Rdb {

 public:
  Fits2Rdb( clo::parser& parser );
  ~Fits2Rdb( void );

  void findColumns( void );
  void findColumns2( void );
  void convertHeader( void );
  void convertTable( void );
  
 private:
  Fits2Rdb( void ) { };
  Fits2Rdb& operator=( const Fits2Rdb& ff ) { if ( this != &ff ) ; return *this; };

  void _initDefaultFormat( void );

  vector<string> _column;
  vector<string> _rcolumn;
  vector<string> _vcolumn;
  vector<string> _rvcolumn;
  vector<string> _ocolumn;
  bool _comment;
  bool _trim;
  map<unsigned char, string> _boolvalue;
  clo::byterep_enum _byterep;
  map<string, string> _defformat;
  map<string, string> _colformat;
  
  Fun _fun;
  FILE* _ofileptr;
  int _maxrow;
  
  int _rowsize;
  int _ncols;

  char* _arraysep;
  
  vector<string> _name;
  char* _sep;
  int* _print;
  int* _type;
  vector<string> _format;
  int* _mode;
  int* _offset;
  int* _n;
  int* _width;
  
};

#endif
