// --8<--8<--8<--8<--
//
// Copyright (C) 2008 Smithsonian Astrophysical Observatory
//
// This file is part of fits2rdb
//
// fits2rdb is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// -->8-->8-->8-->8--

#include <iostream>
#include <suplib/file.h>
using namespace std;

#include <libgen.h>

#include <tracefctxx/TraceFct.h>

#include "usage.hpp"
#include "Options.h"
#include "Fits2Rdb.h"

#include "config.h"

int main( int argc, char* argv[] ) {
  TraceFct tf( argv[0], 0, 0 );
  clo::parser parser;

  try {
     if( getenv( "FITS_EXTNAME" ) == NULL ) {
         char arg[] = "FITS_EXTNAME=EVENTS STDEVT RAYTRACE";
         putenv( arg );
     }

    parser.parse( argc, argv );

    Fits2Rdb f2r( parser );
    f2r.findColumns2( );
    f2r.convertTable( );
    
  } catch ( clo::autoexcept& ae ) {
    switch ( ae.get_autothrow_id( ) ) {
    case clo::autothrow_usage:
      usage( );
      break;      

    case clo::autothrow_help:
      cout << basename( argv[0] ) 
	   << " [options] fitsfile rdbfile\n" 
	   << ae.what( );
      break;

    case clo::autothrow_version:
      cout << basename( argv[0] ) << ":  " << VERSION << "\n";
      break;

    default:
      tf.exit( EXIT_SUCCESS, ae.what( ) );
      break;

    }
  } catch ( clo::option_error& oe ) {
    tf.exit( EXIT_FAILURE, oe.what( ) );

  } catch ( exception& e ) {
    tf.exit( EXIT_FAILURE, e.what( ) );

  } catch ( ... ) {
    tf.exit( EXIT_FAILURE, "Unknown exception caught" );

  }

  return EXIT_SUCCESS;

}
